#! /usr/bin/env python3

# SPDX-FileCopyrightText: 2020 Alchemy-Meister
#
# SPDX-License-Identifier: GPL-3.0-or-later


"""Python Design Patterns."""

from ._about import (
    __author__,
    __author_email__,
    __description__,
    __license__,
    __title__,
    __url__,
    __version__
)

__all__ = [
    '__author__',
    '__author_email__',
    '__description__',
    '__license__',
    '__title__',
    '__url__',
    '__version__'
]
