#! /usr/bin/env python3

# SPDX-FileCopyrightText: 2020 Alchemy-Meister
#
# SPDX-License-Identifier: GPL-3.0-or-later

"""Subpackage with the definition of the metadata of Design-Pyttern package."""

__author__ = 'Alchemy-Meister'
__author_email__ = 'meister.alchemy@gmail.com'
__description__ = 'Implementation of Basic Python Design Patters'
__license__ = 'GPL-3.0-or-later'
__title__ = 'design-pytterns'
__url__ = 'https://github.com/Alchemy-Meister/python-design-patterns'
__version__ = '0.4.0'
