#! /usr/bin/env python3

# SPDX-FileCopyrightText: 2020 Alchemy-Meister
#
# SPDX-License-Identifier: GPL-3.0-or-later

"""Package with interface-like classes."""

from .subclass_identifiable import SubclassIdentifiable

__all__ = ['SubclassIdentifiable']
