#! /usr/bin/env python3

# SPDX-FileCopyrightText: 2020 Alchemy-Meister
#
# SPDX-License-Identifier: GPL-3.0-or-later

"""Subpackage with internal helper classes."""

from .concrete_subclass_register import ConcreteSubclassRegister

__all__ = ['ConcreteSubclassRegister']
